import mksc
from mksc.feature_engineering import preprocess
from mksc.feature_engineering import FeatureEngineering
from custom import Custom

def main(**kwargs):
    """
    项目特征工程程序入口
    """
    # 加载数据、变量类型划分、特征集与标签列划分
    data = mksc.load_data()
    numeric_var, category_var, datetime_var, label_var = preprocess.get_variable_type()
    feature = data[numeric_var + category_var + datetime_var]
    label = data[label_var]

    # 自定义数据清洗
    feature, label = Custom.clean_data(feature, label)

    # 数据类型转换
    feature[numeric_var] = feature[numeric_var].astype('float')
    feature[category_var] = feature[category_var].astype('object')
    feature[datetime_var] = feature[datetime_var].astype('datetime64')

    # 自定义特征组合
    feature = Custom.feature_combination(feature)

    # 标准化特征工程
    fe = FeatureEngineering(feature, label, **kwargs)
    fe.run()


if __name__ == "__main__":
    main()



import eda
import train
import score
import apply


def main():
    tag = input("step 1: 请完成项目配置configuration.ini，完成请输入【Y】")
    if tag.upper() != "Y":
        return

    tag = input("step2: EDA过程...跳过请输入【S】")
    if tag.upper() != "S":
        eda.main()

    tag = input("step 3: 请完成特征配置variable_type.csv以及自定义配置custom.py，完成请输入【Y】，跳过训练过程请输入【S】")
    if tag.upper() == "Y":
        print("训练过程...")
        train.main()
    elif tag.upper() != "S":
        return

    tag = input("step4: 打分过程....跳过请输入【S】")
    if tag.upper() == "Y" or tag == "S":
        score.main()

    print("step6: 应用过程...")
    apply.main()


if __name__ == "__main__":
    main()
